@@ -42,10 +42,10 @@ class Cli:
                             arguments=['region', 'accessKeyId', 'accessKeySecret'],
                             usage='''Usage: %s login <region> [accessKeyId] [accessKeySecret] [option]
 
-          Examples:
+    Examples:
 
-             1. %s login cn-qingdao kywj6si2hkdfy9 las****bc=
-             2. %s login cn-qingdao ''' % (COMMAND, CMD, CMD))
+        1. %s login cn-qingdao kywj6si2hkdfy9 las****bc=
+        2. %s login cn-qingdao ''' % (COMMAND, CMD, CMD))
         self.program.action(cmd_login)
 
         # set config
@@ -53,10 +53,11 @@ class Cli:
                              detail=MSG['config']['detail'],
                              usage='''Usage: %s <command> config|me|set [option]
 
-          Examples:
-             1. %s config     # show configurations
-             2. %s set -r cn-qingdao -o oss://my-bucket/bcscli/ -l zh_CN
-             3. %s set -i %s -t %s ''' % (COMMAND, CMD, CMD,CMD ,IMG_ID, INS_TYPE),
+    Examples:
+
+        1. %s config     # show configurations
+        2. %s set -r cn-qingdao -o oss://my-bucket/bcscli/ -l zh_CN
+        3. %s set -i %s -t %s ''' % (COMMAND, CMD, CMD,CMD ,IMG_ID, INS_TYPE),
                              func=config.all)
         cmd_config.option('-r,--region [region]', MSG['config']['option']['region'])
         cmd_config.option('-o,--osspath [osspath]', MSG['config']['option']['osspath'] )
@@ -80,9 +81,9 @@ class Cli:
                                     description=MSG['instance_type']['description'],
                                     usage='''Usage: %s instance_type|it|t [option]
 
-          Examples:
+    Examples:
 
-              1. %s t ''' % (COMMAND, CMD),
+        1. %s t ''' % (COMMAND, CMD),
                                     spliter='\n    -----%s---------------------------' % blue('query, show'),
                                     func=instance_type.list)
         self.program.action(cmd_instance_type)
@@ -96,14 +97,14 @@ class Cli:
                                description=MSG['cluster']['description'],
                                usage='''Usage: %s cluster|c [clusterId|No.] [option]
 
-          Examples:
+    Examples:
 
-            list cluster:
-              1. %s c
+        list cluster:
+          1. %s c
 
-            get cluster info:
-              1. %s c cls-6ki4fsea5ldlvsupbrk01q
-              2. %s c 1''' % (COMMAND, CMD, CMD, CMD),
+        get cluster info:
+          1. %s c cls-6ki4fsea5ldlvsupbrk01q
+          2. %s c 1''' % (COMMAND, CMD, CMD, CMD),
                                func=cluster.all)
         cmd_clusters.option('-d, --description', MSG['cluster']['option']['description'])
         self.program.action(cmd_clusters)
@@ -117,31 +118,31 @@ class Cli:
                           description=MSG['job']['description'],
                           usage='''Usage:
 
-            %s job|j [jobId|No.] [taskName|No.] [instanceId] [options]
+    %s job|j [jobId|No.] [taskName|No.] [instanceId] [options]
 
-          Examples:
+    Examples:
 
-            list jobs:
-              1. %s job|j -t [num] -s [state] -i [jobId] -n [jobName]
-              2. %s j                     # show top 10 (default)
-              3. %s j -t 50               # show top 50
-              4. %s j -a                  # show all
-              5. %s j -s Running,Waiting  # show those state is Running or Waiting
-              6. %s j -n abc              # show those jobName contains "abc"
-              7. %s j -i 0018             # show those jobId contains "0018"
+        list jobs:
+          1. %s job|j -t [num] -s [state] -i [jobId] -n [jobName]
+          2. %s j                     # show top 10 (default)
+          3. %s j -t 50               # show top 50
+          4. %s j -a                  # show all
+          5. %s j -s Running,Waiting  # show those state is Running or Waiting
+          6. %s j -n abc              # show those jobName contains "abc"
+          7. %s j -i 0018             # show those jobId contains "0018"
 
-            get job detail:
-              1. %s j <jobId>
-              2. %s j <jobId> -d          # show job description only
-              3. %s j <No.>               # use <No.> instead of <job-id>, this command must run after %s j
+        get job detail:
+          1. %s j <jobId>
+          2. %s j <jobId> -d          # show job description only
+          3. %s j <No.>               # use <No.> instead of <job-id>, this command must run after %s j
 
-            get task detail:
-              1. %s j <jobId> <taskName>
-              2. %s j <No.> <No.>            #use <No.> instead of <jobId> and <taskName>
+        get task detail:
+          1. %s j <jobId> <taskName>
+          2. %s j <No.> <No.>            #use <No.> instead of <jobId> and <taskName>
 
-            get instance detail:
-              1. %s j <jobId> <taskName> <instanceId>
-              2. %s j <No.> <No.> <instanceId>         #use <No.> instead of <jobId> and <taskName>''' % (
+        get instance detail:
+          1. %s j <jobId> <taskName> <instanceId>
+          2. %s j <No.> <No.> <instanceId>         #use <No.> instead of <jobId> and <taskName>''' % (
                           COMMAND, CMD, CMD, CMD,CMD, CMD, CMD, CMD, CMD, CMD, CMD, CMD, CMD, CMD, CMD, CMD),
                           func=job.all)
 
@@ -183,11 +184,11 @@ class Cli:
                                      arguments=['clusterName'],
                                      usage='''Usage: %s create_cluster|cc [option] <clusterName>
 
-          Examples:
+    Examples:
 
-              1. %s cc cluster1
-              2. %s cc cluster2 -n 3
-              3. %s cc cluster2 -i %s -t %s -n 1 -d 'this is description' -u key1:value1,k2:v2''' % (
+        1. %s cc cluster1
+        2. %s cc cluster2 -n 3
+        3. %s cc cluster2 -i %s -t %s -n 1 -d 'this is description' -u key1:value1,k2:v2''' % (
                                      COMMAND, CMD, CMD,CMD, IMG_ID, INS_TYPE),
                                      spliter='\n    -----%s----------------' % blue('create, update, delete'),
                                      func=cluster_create.create_cluster)
@@ -215,10 +216,10 @@ class Cli:
                                   description=MSG['delete_cluster']['description'],
                                   usage='''Usage: %s delete_cluster|dc [clusterId,clusterId2,clusterId3...] [option]
 
-          Examples:
+    Examples:
 
-              1. %s dc cls-idxxx1                # delete cluster with clusterId
-              2. %s dc cls-idxxx1,cls-idxxx2 -y  # delete clusters in silent mode''' % (COMMAND, CMD, CMD),
+        1. %s dc cls-idxxx1                # delete cluster with clusterId
+        2. %s dc cls-idxxx1,cls-idxxx2 -y  # delete clusters in silent mode''' % (COMMAND, CMD, CMD),
                                   func=cluster_delete.del_cluster)
         cmd_del_cluster.option("-y, --yes", MSG['delete_cluster']['option']['yes'])
         self.program.action(cmd_del_cluster)
@@ -247,10 +248,10 @@ class Cli:
                                  description=MSG['create_job']['description'],
                                  usage='''Usage: %s create_job|cj [jsonString] [option]
 
-          Examples:
+    Examples:
 
-              1. %s cj "{\\"Name\\":......}"    #create job from json string
-              2. %s cj -f /path/to/job.json   #create job from json file path''' % (COMMAND, CMD, CMD),
+        1. %s cj "{\\"Name\\":......}"    #create job from json string
+        2. %s cj -f /path/to/job.json   #create job from json file path''' % (COMMAND, CMD, CMD),
                                  func=job_create.create)
         cmd_create_job.option("-f, --filePath [filePath]", MSG['create_job']['option']['filePath'])
         self.program.action(cmd_create_job)
@@ -261,10 +262,10 @@ class Cli:
                                   description=MSG['restart_job']['description'],
                                   usage='''Usage: %s restart_job|rj [jobId,jobId2,jobId3...] [option]
 
-          Examples:
+    Examples:
 
-              1. %s rj job-idxxx1             # restart job with jobId
-              2. %s rj job-idxxx1,job-idxxx2  # restart job with jobIds''' % (COMMAND, CMD, CMD),
+        1. %s rj job-idxxx1             # restart job with jobId
+        2. %s rj job-idxxx1,job-idxxx2  # restart job with jobIds''' % (COMMAND, CMD, CMD),
                                   func=job_restart.restart_job)
         cmd_restart_job.option("-y, --yes", MSG['restart_job']['option']['yes'])
         self.program.action(cmd_restart_job)
@@ -275,10 +276,10 @@ class Cli:
                                description=MSG['stop_job']['description'],
                                usage='''Usage: %s stop_job|sj [jobId,jobId2,jobId3...] [option]
 
-          Examples:
+    Examples:
 
-              1. %s sj job-idxxx1             # stop job with jobId
-              2. %s sj job-idxxx1,job-idxxx2  # stop job with jobIds''' % (COMMAND, CMD, CMD),
+        1. %s sj job-idxxx1             # stop job with jobId
+        2. %s sj job-idxxx1,job-idxxx2  # stop job with jobIds''' % (COMMAND, CMD, CMD),
                                func=job_stop.stop_job)
         cmd_stop_job.option("-y, --yes", MSG['stop_job']['option']['yes'])
         self.program.action(cmd_stop_job)
@@ -289,10 +290,10 @@ class Cli:
                               description=MSG['delete_job']['description'],
                               usage='''Usage: %s delete_job|dj [jobId,jobId2,jobId3...] [option]
 
-          Examples:
+    Examples:
 
-              1. %s dj job-idxxx1             # delete job with jobId
-              2. %s dj job-idxxx1,job-idxxx2  # delete job with jobIds''' % (COMMAND, CMD, CMD),
+        1. %s dj job-idxxx1             # delete job with jobId
+        2. %s dj job-idxxx1,job-idxxx2  # delete job with jobIds''' % (COMMAND, CMD, CMD),
                               func=job_delete.del_job)
         cmd_del_job.option("-y, --yes", MSG['delete_job']['option']['yes'])
         self.program.action(cmd_del_job)
@@ -303,9 +304,9 @@ class Cli:
                                  description=MSG['update_job']['description'],
                                  usage='''Usage: %s update_job|uj <jobId> [option]
 
-          Examples:
+    Examples:
 
-              1. %s uj job-idxxx1 -p 2   #update job set priority=2''' % (COMMAND, CMD),
+        1. %s uj job-idxxx1 -p 2   #update job set priority=2''' % (COMMAND, CMD),
                                  func=job_update.update)
         cmd_update_job.option("-y, --yes",  MSG['update_job']['option']['yes'])
         cmd_update_job.option("-p, --priority <priority>",  MSG['update_job']['option']['priority'])
@@ -358,13 +359,14 @@ class Cli:
                                  description=MSG['submit']['description'],
                                  usage='''Usage: %s submit|sub <cmd> [job_name] [option]
 
-          Examples:
-              1. %s sub "echo 'hello'" -n 3 -f                                                    # run this cmd on 3 machines(instances) in force mode
-              2. %s sub "echo 'hello'" -c img=%s                                         # use auto cluster
-              3. %s sub "python main.py arg1 arg2" job_name -c cls-xxxxx -p ./my_program/         # set job name, use cluster id, pack a folder and upload
-              4. %s sub "python /home/admin/test/main.py" -m oss://bucket/a/b/:/home/admin/test/  # mount an oss path to a local path
-              5. %s sub "python test.py" -p test.py --docker myubuntu@oss://bucket/dockers/       # run in docker container
-              6. %s sub --file job.cfg                    # submit a job from job.cfg''' % (
+    Examples:
+
+        1. %s sub "echo 'hello'" -n 3 -f                                                    # run this cmd on 3 machines(instances) in force mode
+        2. %s sub "echo 'hello'" -c img=%s                                         # use auto cluster
+        3. %s sub "python main.py arg1 arg2" job_name -c cls-xxxxx -p ./my_program/         # set job name, use cluster id, pack a folder and upload
+        4. %s sub "python /home/admin/test/main.py" -m oss://bucket/a/b/:/home/admin/test/  # mount an oss path to a local path
+        5. %s sub "python test.py" -p test.py --docker myubuntu@oss://bucket/dockers/       # run in docker container
+        6. %s sub --file job.cfg                    # submit a job from job.cfg''' % (
                                  COMMAND, CMD, CMD, IMG_ID, CMD, CMD, CMD, CMD),
                                  spliter='\n    -----%s----------------' % blue('quick cmd'),
                                  func=job_submit.submit)
@@ -399,9 +401,9 @@ class Cli:
                                  description=MSG['check']['description'],
                                  usage='''Usage: %s check|ch <jobId|No.> [option]
 
-          Examples:
-              1. %s check job-0000000056D7FE9A0000368000000661
-              2. %s ch 2       # use No. instead of jobId''' % (
+    Examples:
+        1. %s check job-0000000056D7FE9A0000368000000661
+        2. %s ch 2       # use No. instead of jobId''' % (
                                  COMMAND, CMD, CMD),
                                  func=checker.check)
         self.program.action(cmd_check)
@@ -413,7 +415,7 @@ class Cli:
         else:
             try:
                 self.program.parse(arr)
-            except BaseException as e:
+            except Exception as e:
                 msg = format(e)
                 print(red('\n  ERROR: %s\n' % msg))
                 if '()' in msg and 'argument' in msg:
